<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// S
	'svp_description' => 'SVP stellt ein API bereit, mit dem SPIP-Plugins (Zusatzfunktionen, Themen und  Skelette) nach mehreren Kriterien gesucht  und ausgewählt werden können und bietet eine Oberfläche zur Verwaltung der  Plugins sowie ihrer Abhängigkeiten.',
	'svp_slogan' => 'Informations- und Download-Server für Plugins',
];
